@@ -2,80 +2,21 @@ use 5.006;
 use strict;
 use warnings;
 package Email::Simple;
+{
+  $Email::Simple::VERSION = '2.104';
+}
+# ABSTRACT: simple parsing of RFC2822 message format and headers
 
 use Carp ();
 
 use Email::Simple::Creator;
 use Email::Simple::Header;
 
-our $VERSION = '2.103';
 our $GROUCHY = 0;
 
 # We are liberal in what we accept.
 sub __crlf_re { qr/\x0a\x0d|\x0d\x0a|\x0a|\x0d/; }
 
-=head1 NAME
-
-Email::Simple - simple parsing of RFC2822 message format and headers
-
-=head1 SYNOPSIS
-
-  use Email::Simple;
-  my $email = Email::Simple->new($text);
-
-  my $from_header = $email->header("From");
-  my @received = $email->header("Received");
-
-  $email->header_set("From", 'Simon Cozens <simon@cpan.org>');
-
-  my $old_body = $email->body;
-  $email->body_set("Hello world\nSimon");
-
-  print $email->as_string;
-
-...or, to create a message from scratch...
-
-  my $email = Email::Simple->create(
-      header => [
-        From    => 'casey@geeknest.com',
-        To      => 'drain@example.com',
-        Subject => 'Message in a bottle',
-      ],
-      body => '...',
-  );
-  
-  $email->header_set( 'X-Content-Container' => 'bottle/glass' );
-  
-  print $email->as_string;
-
-=head1 DESCRIPTION
-
-C<Email::Simple> is the first deliverable of the "Perl Email Project."  The
-Email:: namespace was begun as a reaction against the increasing complexity and
-bugginess of Perl's existing email modules.  C<Email::*> modules are meant to
-be simple to use and to maintain, pared to the bone, fast, minimal in their
-external dependencies, and correct.
-
-=head1 METHODS
-
-=head2 new
-
-  my $email = Email::Simple->new($message, \%arg);
-
-This method parses an email from a scalar containing an RFC2822 formatted
-message and returns an object.  C<$message> may be a reference to a message
-string, in which case the string will be altered in place.  This can result in
-significant memory savings.
-
-If you want to create a message from scratch, you should use the C<L</create>>
-method.
-
-Valid arguments are:
-
-  header_class - the class used to create new header objects
-                 The named module is not 'require'-ed by Email::Simple!
-
-=cut
 
 sub new {
   my ($class, $text, $arg) = @_;
@@ -128,22 +69,6 @@ sub _split_head_from_body {
   }
 }
 
-=head2 create
-
-  my $email = Email::Simple->create(header => [ @headers ], body => '...');
-
-This method is a constructor that creates an Email::Simple object
-from a set of named parameters. The C<header> parameter's value is a
-list reference containing a set of headers to be created. The C<body>
-parameter's value is a scalar value holding the contents of the message
-body.  Line endings in the body will normalized to CRLF.
-
-If no C<Date> header is specified, one will be provided for you based on the
-C<gmtime> of the local machine. This is because the C<Date> field is a required
-header and is a pain in the neck to create manually for every message. The
-C<From> field is also a required header, but it is I<not> provided for you.
-
-=cut
 
 our $CREATOR = 'Email::Simple::Creator';
 
@@ -180,14 +105,6 @@ sub create {
 }
 
 
-=head2 header_obj
-
-  my $header = $email->header_obj;
-
-This method returns the object representing the email's header.  For the
-interface for this object, see L<Email::Simple::Header>.
-
-=cut
 
 sub header_obj {
   my ($self) = @_;
@@ -199,6 +116,139 @@ sub header_obj {
 # dependency tree to upgrade.  i.e., never and/or in Perl 6 -- rjbs, 2006-11-28
 BEGIN { *__head = \&header_obj }
 
+
+sub header_obj_set {
+  my ($self, $obj) = @_;
+  $self->{header} = $obj;
+}
+
+
+BEGIN {
+  no strict 'refs';
+  for my $method (qw(header header_set header_names header_pairs)) {
+    *$method = sub { (shift)->header_obj->$method(@_) };
+  }
+  *headers = \&header_names;
+}
+
+
+sub body {
+  my ($self) = @_;
+  return (defined ${ $self->{body} }) ? ${ $self->{body} } : '';
+}
+
+
+sub body_set {
+  my ($self, $text) = @_;
+  my $text_ref = ref $text ? $text : \$text;
+  $self->{body} = $text_ref;
+  return;
+}
+
+
+sub as_string {
+  my $self = shift;
+  return $self->header_obj->as_string . $self->crlf . $self->body;
+}
+
+
+sub crlf { $_[0]->{mycrlf} }
+
+
+sub default_header_class { 'Email::Simple::Header' }
+
+1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Email::Simple - simple parsing of RFC2822 message format and headers
+
+=head1 VERSION
+
+version 2.104
+
+=head1 SYNOPSIS
+
+  use Email::Simple;
+  my $email = Email::Simple->new($text);
+
+  my $from_header = $email->header("From");
+  my @received = $email->header("Received");
+
+  $email->header_set("From", 'Simon Cozens <simon@cpan.org>');
+
+  my $old_body = $email->body;
+  $email->body_set("Hello world\nSimon");
+
+  print $email->as_string;
+
+...or, to create a message from scratch...
+
+  my $email = Email::Simple->create(
+      header => [
+        From    => 'casey@geeknest.com',
+        To      => 'drain@example.com',
+        Subject => 'Message in a bottle',
+      ],
+      body => '...',
+  );
+  
+  $email->header_set( 'X-Content-Container' => 'bottle/glass' );
+  
+  print $email->as_string;
+
+=head1 DESCRIPTION
+
+The Email:: namespace was begun as a reaction against the increasing complexity
+and bugginess of Perl's existing email modules.  C<Email::*> modules are meant
+to be simple to use and to maintain, pared to the bone, fast, minimal in their
+external dependencies, and correct.
+
+=head1 METHODS
+
+=head2 new
+
+  my $email = Email::Simple->new($message, \%arg);
+
+This method parses an email from a scalar containing an RFC2822 formatted
+message and returns an object.  C<$message> may be a reference to a message
+string, in which case the string will be altered in place.  This can result in
+significant memory savings.
+
+If you want to create a message from scratch, you should use the C<L</create>>
+method.
+
+Valid arguments are:
+
+  header_class - the class used to create new header objects
+                 The named module is not 'require'-ed by Email::Simple!
+
+=head2 create
+
+  my $email = Email::Simple->create(header => [ @headers ], body => '...');
+
+This method is a constructor that creates an Email::Simple object
+from a set of named parameters. The C<header> parameter's value is a
+list reference containing a set of headers to be created. The C<body>
+parameter's value is a scalar value holding the contents of the message
+body.  Line endings in the body will normalized to CRLF.
+
+If no C<Date> header is specified, one will be provided for you based on the
+C<gmtime> of the local machine. This is because the C<Date> field is a required
+header and is a pain in the neck to create manually for every message. The
+C<From> field is also a required header, but it is I<not> provided for you.
+
+=head2 header_obj
+
+  my $header = $email->header_obj;
+
+This method returns the object representing the email's header.  For the
+interface for this object, see L<Email::Simple::Header>.
+
 =head2 header_obj_set
 
   $email->header_obj_set($new_header_obj);
@@ -206,13 +256,6 @@ BEGIN { *__head = \&header_obj }
 This method substitutes the given new header object for the email's existing
 header object.
 
-=cut
-
-sub header_obj_set {
-  my ($self, $obj) = @_;
-  $self->{header} = $obj;
-}
-
 =head2 header
 
   my @values = $email->header($header_name);
@@ -248,73 +291,28 @@ This method returns a list of pairs describing the contents of the header.
 Every other value, starting with and including zeroth, is a header name and the
 value following it is the header value.
 
-=cut
-
-BEGIN {
-  no strict 'refs';
-  for my $method (qw(header header_set header_names header_pairs)) {
-    *$method = sub { (shift)->header_obj->$method(@_) };
-  }
-  *headers = \&header_names;
-}
-
 =head2 body
 
 Returns the body text of the mail.
 
-=cut
-
-sub body {
-  my ($self) = @_;
-  return (defined ${ $self->{body} }) ? ${ $self->{body} } : '';
-}
-
 =head2 body_set
 
 Sets the body text of the mail.
 
-=cut
-
-sub body_set {
-  my ($self, $text) = @_;
-  my $text_ref = ref $text ? $text : \$text;
-  $self->{body} = $text_ref;
-  return;
-}
-
 =head2 as_string
 
 Returns the mail as a string, reconstructing the headers.
 
-=cut
-
-sub as_string {
-  my $self = shift;
-  return $self->header_obj->as_string . $self->crlf . $self->body;
-}
-
 =head2 crlf
 
 This method returns the type of newline used in the email.  It is an accessor
 only.
 
-=cut
-
-sub crlf { $_[0]->{mycrlf} }
-
 =head2 default_header_class
 
 This returns the class used, by default, for header objects, and is provided
 for subclassing.  The default default is Email::Simple::Header.
 
-=cut
-
-sub default_header_class { 'Email::Simple::Header' }
-
-1;
-
-__END__
-
 =head1 CAVEATS
 
 Email::Simple handles only RFC2822 formatted messages.  This means you cannot
@@ -324,24 +322,29 @@ say for example when writing a mail filter for invocation from a .forward file
 on this issue please consult RT issue 2478,
 L<http://rt.cpan.org/NoAuth/Bug.html?id=2478>.
 
-=head1 PERL EMAIL PROJECT
-
-This module is maintained by the Perl Email Project
-
-L<http://emailproject.perl.org/>
-
 =head1 AUTHORS
 
-Simon Cozens originally wrote Email::Simple in 2003.  Casey West took over
-maintenance in 2004, and Ricardo SIGNES took over maintenance in 2006.
+=over 4
+
+=item *
+
+Simon Cozens
+
+=item *
+
+Casey West
+
+=item *
+
+Ricardo SIGNES
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004 by Casey West
+This software is copyright (c) 2003 by Simon Cozens.
 
-Copyright 2003 by Simon Cozens
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
