@@ -1,42 +1,14 @@
-package Email::Simple::Header;
-
 use strict;
+use warnings;
+package Email::Simple::Header;
+{
+  $Email::Simple::Header::VERSION = '2.104';
+}
+# ABSTRACT: the header of an Email::Simple message
 use Carp ();
 
 require Email::Simple;
 
-$Email::Simple::Header::VERSION = '2.103';
-
-=head1 NAME
-
-Email::Simple::Header - the header of an Email::Simple message
-
-=head1 SYNOPSIS
-
-  my $email = Email::Simple->new($text);
-
-  my $header = $email->head;
-  print $header->as_string;
-
-=head1 DESCRIPTION
-
-This method implements the headers of an Email::Simple object.  It is a very
-minimal interface, and is mostly for private consumption at the moment.
-
-=head1 METHODS
-
-=head2 new
-
-  my $header = Email::Simple::Header->new($head, \%arg);
-
-C<$head> is a string containing a valid email header, or a reference to such a
-string.  If a reference is passed in, don't expect that it won't be altered.
-
-Valid arguments are:
-
-  crlf - the header's newline; defaults to CRLF
-
-=cut
 
 # We need to be able to:
 #   * get all values by lc name
@@ -71,27 +43,23 @@ sub _header_to_list {
 
   while ($$head =~ m/\G(.+?)$crlf/go) {
     local $_ = $1;
-    if (s/^\s+// or not /^([^:]+):\s*(.*)/) {
+
+    if (/^\s+/ or not /^([^:]+):\s*(.*)/) {
       # This is a continuation line. We fold it onto the end of
       # the previous header.
       next if !@headers;  # Well, that sucks.  We're continuing nothing?
 
-      $headers[-1] .= $headers[-1] =~ /\S/ ? " $_" : $_;
+      (my $trimmed = $_) =~ s/^\s+//;
+      $headers[-1][0] .= $headers[-1][0] =~ /\S/ ? " $trimmed" : $trimmed;
+      $headers[-1][1] .= "$mycrlf$_";
     } else {
-      push @headers, $1, $2;
+      push @headers, $1, [ $2, $_ ];
     }
   }
 
   return \@headers;
 }
 
-=head2 as_string
-
-  my $string = $header->as_string(\%arg);
-
-This returns a stringified version of the header.
-
-=cut
 
 # RFC 2822, 3.6:
 # ...for the purposes of this standard, header fields SHOULD NOT be reordered
@@ -115,22 +83,18 @@ sub as_string {
   };
 
   for (my $i = 0; $i < @$headers; $i += 2) {
-    my $header = "$headers->[$i]: $headers->[$i + 1]";
+    if (ref $headers->[ $i + 1 ]) {
+      $header_str .= $headers->[ $i + 1 ][1] . $self->crlf;
+    } else {
+      my $header = "$headers->[$i]: $headers->[$i + 1]";
 
-    $header_str .= lc $headers->[$i] eq 'content-type'
-                 ? $header . $self->crlf
-                 : $self->_fold($header, $fold_arg);
+      $header_str .= $self->_fold($header, $fold_arg);
+    }
   }
 
   return $header_str;
 }
 
-=head2 header_names
-
-This method returns the unique header names found in this header, in no
-particular order.
-
-=cut
 
 sub header_names {
   my $headers = $_[0]->{headers};
@@ -140,28 +104,17 @@ sub header_names {
     map { $headers->[ $_ * 2 ] } 0 .. int($#$headers / 2);
 }
 
-=head2 header_pairs
-
-This method returns all the field/value pairs in the header, in the order that
-they appear in the header.
-
-=cut
 
 sub header_pairs {
   my ($self) = @_;
 
-  return @{ $self->{headers} };
+  my @pairs = map {; _str_value($_) } @{ $self->{headers} };
+
+  return @pairs;
 }
 
-=head2 header
 
-  my $first_value = $header->header($field);
-  my @all_values  = $header->header($field);
-
-This method returns the value or values of the given header field.  If the
-named field does not appear in the header, this method returns false.
-
-=cut
+sub _str_value { return ref $_[0] ? $_[0][0] : $_[0] }
 
 sub header {
   my ($self, $field) = @_;
@@ -170,25 +123,16 @@ sub header {
   my $lc_field = lc $field;
 
   if (wantarray) {
-    return map { @$headers[ $_ * 2 + 1 ] }
+    return map { _str_value($headers->[ $_ * 2 + 1 ]) }
       grep { lc $headers->[ $_ * 2 ] eq $lc_field } 0 .. int($#$headers / 2);
   } else {
     for (0 .. int($#$headers / 2)) {
-      return $headers->[ $_ * 2 + 1 ] if lc $headers->[ $_ * 2 ] eq $lc_field;
+      return _str_value($headers->[ $_ * 2 + 1 ]) if lc $headers->[ $_ * 2 ] eq $lc_field;
     }
     return;
   }
 }
 
-=head2 header_set
-
-  $header->header_set($field => @values);
-
-This method updates the value of the given header.  Existing headers have their
-values set in place.  Additional headers are added at the end.  If no values
-are given to set, the header will be removed from to the message entirely.
-
-=cut
 
 # Header fields are lines composed of a field name, followed by a colon (":"),
 # followed by a field body, and terminated by CRLF.  A field name MUST be
@@ -235,15 +179,10 @@ sub header_set {
   return wantarray ? @data : $data[0];
 }
 
-=head2 crlf
-
-This method returns the newline string used in the header.
-
-=cut
 
 sub crlf { $_[0]->{mycrlf} }
 
-# =head2 fold
+# =method fold
 # 
 #   my $folded = $header->fold($line, \%arg);
 # 
@@ -290,7 +229,7 @@ sub _fold {
   return $folded;
 }
 
-# =head2 default_fold_at
+# =method default_fold_at
 # 
 # This method (provided for subclassing) returns the default length at which to
 # try to fold header lines.  The default default is 78.
@@ -299,7 +238,7 @@ sub _fold {
 
 sub _default_fold_at { 78 }
 
-# =head2 default_fold_indent
+# =method default_fold_indent
 # 
 # This method (provided for subclassing) returns the default string used to
 # indent folded headers.  The default default is a single space.
@@ -308,23 +247,109 @@ sub _default_fold_at { 78 }
 
 sub _default_fold_indent { " " }
 
-=head1 PERL EMAIL PROJECT
+1;
 
-This module is maintained by the Perl Email Project
+__END__
 
-L<http://emailproject.perl.org/>
+=pod
+
+=head1 NAME
+
+Email::Simple::Header - the header of an Email::Simple message
+
+=head1 VERSION
+
+version 2.104
+
+=head1 SYNOPSIS
+
+  my $email = Email::Simple->new($text);
+
+  my $header = $email->header_obj;
+  print $header->as_string;
+
+=head1 DESCRIPTION
+
+This method implements the headers of an Email::Simple object.  It is a very
+minimal interface, and is mostly for private consumption at the moment.
+
+=head1 METHODS
+
+=head2 new
+
+  my $header = Email::Simple::Header->new($head, \%arg);
+
+C<$head> is a string containing a valid email header, or a reference to such a
+string.  If a reference is passed in, don't expect that it won't be altered.
+
+Valid arguments are:
+
+  crlf - the header's newline; defaults to CRLF
+
+=head2 as_string
+
+  my $string = $header->as_string(\%arg);
+
+This returns a stringified version of the header.
+
+=head2 header_names
+
+This method returns a list of the unique header names found in this header, in
+no particular order.
+
+=head2 header_pairs
+
+  my @pairs = $header->header_pairs;
+  my $first_name  = $pairs[0];
+  my $first_value = $pairs[1];
+
+This method returns a list of all the field/value pairs in the header, in the
+order that they appear in the header.  (Remember: don't try assigning that to a
+hash.  Some fields may appear more than once!)
+
+=head2 header
+
+  my $first_value = $header->header($field);
+  my @all_values  = $header->header($field);
+
+This method returns the value or values of the given header field.  If the
+named field does not appear in the header, this method returns false.
+
+=head2 header_set
+
+  $header->header_set($field => @values);
+
+This method updates the value of the given header.  Existing headers have their
+values set in place.  Additional headers are added at the end.  If no values
+are given to set, the header will be removed from to the message entirely.
+
+=head2 crlf
+
+This method returns the newline string used in the header.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Simon Cozens
+
+=item *
+
+Casey West
+
+=item *
+
+Ricardo SIGNES
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2007 by Ricardo SIGNES
+This software is copyright (c) 2003 by Simon Cozens.
 
-Copyright 2004 by Casey West
-
-Copyright 2003 by Simon Cozens
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
